@@ -2,7 +2,7 @@
 #Paste = function(x,...) paste(x,...,sep="",collapse="")
 
 ## CONSTANTS
-widthOfChar <- ceiling(as.numeric(tclvalue(tcl("font","measure","TkTextFont","0123456789")))/10)
+widthOfChar <- ceiling(as.numeric(tclvalue(tcl("font","measure","TkTextFont","0"))))
 heightOfChar <-  as.numeric(as.character(tcl("font","metrics","TkTextFont"))[6])
 xyToAnchor = function(anchor) {
   m = rbind(
@@ -19,7 +19,7 @@ isMac <- function() {
 }
 DEBUG = function(...) {
   if(0)
-    cat(paste(...,sep=" ",collapse=" "),"\n")
+    message(paste(...,sep=" ",collapse=" "),"\n")
 }
 
 ## paste() helpers
