@@ -310,7 +310,7 @@ setMethod(".gbasicdialog",
                    action = NULL,
                    ...
                    ) {
-            cat(gettext("gbasiddialog isn't implemented in tcltk"),"\n")
+            message(gettext("gbasiddialog isn't implemented in tcltk"),"\n")
             return()
           })
 
@@ -410,8 +410,9 @@ setMethod(".visible",
                          tclvalue(flag) <- "destroy"
                        })
 
-                     ## make window visible
+                     ## make window visible and on top of stack
                      visible(dlg) <- TRUE
+                     focus(dlg) <- TRUE
                      ## make modal
                      tkwait.variable(flag)
 
